@@ -1,5 +1,5 @@
 <?php
-declare(encoding = 'utf-8');
+//declare(encoding = 'utf-8');
 require_once 'confusa_gen.php';
 
 /**
